Planar Documentation Contents — Planar v0.4 documentation

### Navigation

- index
- modules |
- next |
- Planar v0.4 documentation »

# Planar Documentation Contents

Planar is a 2D geometry library for Python designed for use by games and other interactive applications.

Planar was created for use by the Grease game framework, but is distributed as a separate standalone library so that it can be more useful for everyone.

- Planar Overview
  - Project Goals
  - License
  - Acknowledgements
  - Requirements
  - Downloading Planar
  - Installation
  - Tests
  - Documentation
  - Contributing and Getting Support
- Usage Guide
  - Importing Classes
  - Implementation Differences
  - Angles
- Vector Objects
  - Vector Sequences
- Transform Objects
  - Affine Transforms
- BoundingBox Objects
  - BoundingBox Attributes
  - “Hit” Testing
  - BoundingBox Operations
- Polygon Objects
  - Classifying Polygons
  - Other Attributes
  - Creating Convex Polygons
  - Polygon Operations

## Reference

- `planar` – Global Definitions
- `planar.Vec2` – 2D Vectors
- `planar.Vec2Array` – 2D Vector Arrays
- `planar.Affine` – 2D Affine Transforms
- `planar.Line` – Infinite Lines
- `planar.Ray` – Infinite Semi-Lines
- `planar.LineSegment` – Line Segments
- `planar.BoundingBox` – Bounding Boxes
- `planar.Polygon` – Polygonal Shapes

## Release Notes

- Release 0.4 (3/21/2011)
- Release 0.3 (2/26/2011)
- Release 0.2.1 (8/24/2010)
- Release 0.2 (8/21/2010)
- Release 0.1 (4/27/2010)

# Indices and tables

- Index
- Search Page

### Navigation

- index
- modules |
- next |
- Planar v0.4 documentation »